var indexSectionsWithContent =
{
  0: "1234567abcdefghijklmnopqrstuvwz~",
  1: "abcdefghijklmnoprstuvwz",
  2: "gs",
  3: "abcdefghijklmnoprstuvwz~",
  4: "abcdefghiklmnoprstu",
  5: "acdefhinprstuv",
  6: "acilmpt",
  7: "acfilmnoprsuz",
  8: "o",
  9: "bcdefhjlmoprs",
  10: "abcdefghiklmnoprst"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "related",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Friends",
  9: "Modules",
  10: "Pages"
};

